==> solc_0.8.24.orig.tar.gz: test/libsolidity/GasTest.h <==
/*
	This file is part of solidity.

	solidity is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	solidity is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with solidity.  If not, see <http://www.gnu.org/licenses/>.
*/
// SPDX-License-Identifier: GPL-3.0

#pragma once

#include <test/libsolidity/AnalysisFramework.h>
#include <test/TestCase.h>
#include <liblangutil/Exceptions.h>

#include <libsolidity/interface/OptimiserSettings.h>

#include <iosfwd>
#include <string>
#include <vector>
#include <utility>

namespace solidity::frontend::test
{

class GasTest: AnalysisFramework, public TestCase
{
public:
	static std::unique_ptr<TestCase> create(Config const& _config)
	{ return std::make_unique<GasTest>(_config.filename); }
	GasTest(std::string const& _filename);

	TestResult run(std::ostream& _stream, std::string const& _linePrefix = "", bool _formatted = false) override;

	void printUpdatedExpectations(std::ostream& _stream, std::string const& _linePrefix) const override;

protected:
	void setupCompiler(CompilerStack& _compiler) override;

private:
	void parseExpectations(std::istream& _stream);

	bool m_optimise = false;
	bool m_optimiseYul = false;
	size_t m_optimiseRuns = OptimiserSettings{}.expectedExecutionsPerDeployment;
	std::map<std::string, std::map<std::string, std::string>> m_expectations;
};

}

==> solc_0.8.30.orig.tar.gz: test/libsolidity/GasTest.h <==
/*
	This file is part of solidity.

	solidity is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	solidity is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with solidity.  If not, see <http://www.gnu.org/licenses/>.
*/
// SPDX-License-Identifier: GPL-3.0

#pragma once

#include <test/libsolidity/AnalysisFramework.h>
#include <test/TestCase.h>
#include <liblangutil/Exceptions.h>

#include <libsolidity/interface/OptimiserSettings.h>

#include <iosfwd>
#include <string>
#include <vector>
#include <utility>

namespace solidity::frontend::test
{

class GasTest: AnalysisFramework, public EVMVersionRestrictedTestCase
{
public:
	static std::unique_ptr<TestCase> create(Config const& _config)
	{ return std::make_unique<GasTest>(_config.filename); }
	GasTest(std::string const& _filename);

	TestResult run(std::ostream& _stream, std::string const& _linePrefix = "", bool _formatted = false) override;

	void printUpdatedExpectations(std::ostream& _stream, std::string const& _linePrefix) const override;

protected:
	void setupCompiler(CompilerStack& _compiler) override;

private:
	void parseExpectations(std::istream& _stream);

	bool m_optimise = false;
	bool m_optimiseYul = false;
	size_t m_optimiseRuns = OptimiserSettings{}.expectedExecutionsPerDeployment;
	std::map<std::string, std::map<std::string, std::string>> m_expectations;
};

}
